@@ -14,7 +14,6 @@ from collections import deque
 import linecache
 import traceback
 import os.path
-import contextvars
 
 log = logging.getLogger(__name__)
 
@@ -142,9 +141,6 @@ class Task(object):
         # Timeout deadline stack
         self._deadlines = []
 
-        # Contextvars support
-        self._context = contextvars.copy_context()
-
     def __repr__(self):
         return f'{type(self).__name__}(id={self.id}, name={self.name!r}, state={self.state!r})'
 
@@ -160,6 +156,7 @@ class Task(object):
         if not self.joined and not self.cancelled and not self.daemon:
             if not self.daemon and not self.exception:
                 log.warning('%r never joined', self)
+        assert not self._last_io
 
     def send(self, value):
         '''
@@ -264,6 +261,7 @@ class ContextTask(Task):
     taskcls keyword argument to the Curio kernel.
     '''
     def __init__(self, coro):
+        import contextvars
         super().__init__(coro)
         self._context = contextvars.copy_context()
 
@@ -390,6 +388,8 @@ class TaskGroup(object):
     def result(self):
         if not self._joined:
             raise RuntimeError("Task group not yet terminated")
+        if not self.completed:
+            raise RuntimeError("No task successfully completed")
         return self.completed.result
 
     # Property that returns the exception of the first completed task
@@ -397,7 +397,7 @@ class TaskGroup(object):
     def exception(self):
         if not self._joined:
             raise RuntimeError("Task group not yet terminated")
-        return self.completed.exception
+        return self.completed.exception if self.completed else None
 
     # Property that returns all task results (in task creation order)
     @property
